Coverage for tictactoe/contest/migrations/0004_auto_20140407_1808: 100%

# Coverage for tictactoe/contest/migrations/0004_auto_20140407_1808 : 100%

## 5 statements 5 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 | # encoding: utf8 from django.db import models, migrations import datetime class Migration(migrations.Migration): dependencies = [ ('contest', '0003_latestentry'), ] operations = [ migrations.AddField( model_name='fight', name='modified', field=models.DateTimeField(default=datetime.datetime(2014, 4, 7, 18, 8, 23, 959301), auto_now=True), preserve_default=False, ), migrations.AddField( model_name='fight', name='created', field=models.DateTimeField(default=datetime.datetime(2014, 4, 7, 18, 8, 28, 908912), auto_now_add=True), preserve_default=False, ), ]